@@ -4,6 +4,7 @@ import xarray as xr
 
 from .base import dict_to_dataset
 from .inference_data import InferenceData
+from .io_beanmachine import from_beanmachine
 from .io_cmdstan import from_cmdstan
 from .io_cmdstanpy import from_cmdstanpy
 from .io_emcee import from_emcee
@@ -32,6 +33,7 @@ def convert_to_inference_data(obj, *, group="posterior", coords=None, dims=None,
             | pymc3 trace: Automatically extracts data
             | emcee sampler: Automatically extracts data
             | pyro MCMC: Automatically extracts data
+            | beanmachine MonteCarloSamples: Automatically extracts data
             | xarray.Dataset: adds to InferenceData as only group
             | xarray.DataArray: creates an xarray dataset as the only group, gives the
                          array an arbitrary name, if name not set
@@ -91,6 +93,8 @@ def convert_to_inference_data(obj, *, group="posterior", coords=None, dims=None,
         return from_pymc3(trace=kwargs.pop(group), **kwargs)
     elif obj.__class__.__name__ == "EnsembleSampler":  # ugly, but doesn't make emcee a requirement
         return from_emcee(sampler=kwargs.pop(group), **kwargs)
+    elif obj.__class__.__name__ == "MonteCarloSamples":
+        return from_beanmachine(sampler=kwargs.pop(group), **kwargs)
     elif obj.__class__.__name__ == "MCMC" and obj.__class__.__module__.startswith("pyro"):
         return from_pyro(posterior=kwargs.pop(group), **kwargs)
     elif obj.__class__.__name__ == "MCMC" and obj.__class__.__module__.startswith("numpyro"):
@@ -129,9 +133,8 @@ def convert_to_inference_data(obj, *, group="posterior", coords=None, dims=None,
             "cmdstanpy fit",
         )
         raise ValueError(
-            "Can only convert {} to InferenceData, not {}".format(
-                ", ".join(allowable_types), obj.__class__.__name__
-            )
+            f'Can only convert {", ".join(allowable_types)} to InferenceData, '
+            f"not {obj.__class__.__name__}"
         )
 
     return InferenceData(**{group: dataset})
@@ -151,16 +154,18 @@ def convert_to_dataset(obj, *, group="posterior", coords=None, dims=None):
     ----------
     obj : dict, str, np.ndarray, xr.Dataset, pystan fit, pymc3 trace
         A supported object to convert to InferenceData:
-            InferenceData: returns unchanged
-            str: Attempts to load the netcdf dataset from disk
-            pystan fit: Automatically extracts data
-            pymc3 trace: Automatically extracts data
-            xarray.Dataset: adds to InferenceData as only group
-            xarray.DataArray: creates an xarray dataset as the only group, gives the
-                         array an arbitrary name, if name not set
-            dict: creates an xarray dataset as the only group
-            numpy array: creates an xarray dataset as the only group, gives the
-                         array an arbitrary name
+
+        - InferenceData: returns unchanged
+        - str: Attempts to load the netcdf dataset from disk
+        - pystan fit: Automatically extracts data
+        - pymc3 trace: Automatically extracts data
+        - xarray.Dataset: adds to InferenceData as only group
+        - xarray.DataArray: creates an xarray dataset as the only group, gives the
+          array an arbitrary name, if name not set
+        - dict: creates an xarray dataset as the only group
+        - numpy array: creates an xarray dataset as the only group, gives the
+          array an arbitrary name
+
     group : str
         If `obj` is a dict or numpy array, assigns the resulting xarray
         dataset to this group.
