@@ -3,10 +3,12 @@ import numpy as np
 import xarray as xr
 
 from ..data import convert_to_dataset
+from ..labels import BaseLabeller
 from ..rcparams import rcParams
+from ..sel_utils import xarray_var_iter
 from ..stats import ess
 from ..utils import _var_names, get_coords
-from .plot_utils import default_grid, filter_plotters_list, get_plotting_function, xarray_var_iter
+from .plot_utils import default_grid, filter_plotters_list, get_plotting_function
 
 
 def plot_ess(
@@ -24,6 +26,7 @@ def plot_ess(
     n_points=20,
     extra_methods=False,
     min_ess=400,
+    labeller=None,
     ax=None,
     extra_kwargs=None,
     text_kwargs=None,
@@ -32,29 +35,29 @@ def plot_ess(
     backend=None,
     backend_kwargs=None,
     show=None,
-    **kwargs
+    **kwargs,
 ):
     """Plot quantile, local or evolution of effective sample sizes (ESS).
 
     Parameters
     ----------
     idata: obj
-        Any object that can be converted to an az.InferenceData object
-        Refer to documentation of az.convert_to_dataset for details
+        Any object that can be converted to an :class:`arviz.InferenceData` object
+        Refer to documentation of :func:`arviz.convert_to_dataset` for details
     var_names: list of variable names, optional
-        Variables to be plotted. Prefix the variables by `~` when you want to exclude
+        Variables to be plotted. Prefix the variables by ``~`` when you want to exclude
         them from the plot.
     filter_vars: {None, "like", "regex"}, optional, default=None
         If `None` (default), interpret var_names as the real variables names. If "like",
         interpret var_names as substrings of the real variables names. If "regex",
         interpret var_names as regular expressions on the real variables names. A la
-        `pandas.filter`.
+        ``pandas.filter``.
     kind: str, optional
         Options: ``local``, ``quantile`` or ``evolution``, specify the kind of plot.
     relative: bool
         Show relative ess in plot ``ress = ess / N``.
     coords: dict, optional
-        Coordinates of var_names to be plotted. Passed to `Dataset.sel`
+        Coordinates of var_names to be plotted. Passed to :meth:`xarray.Dataset.sel`.
     grid : tuple
         Number of rows and columns. Defaults to None, the rows and columns are
         automatically inferred.
@@ -73,7 +76,12 @@ def plot_ess(
     extra_methods: bool, optional
         Plot mean and sd ESS as horizontal lines. Not taken into account in evolution kind
     min_ess: int
-        Minimum number of ESS desired.
+        Minimum number of ESS desired. If ``relative=True`` the line is plotted at
+        ``min_ess / n_samples`` for local and quantile kinds and as a curve following
+        the ``min_ess / n`` dependency in evolution kind.
+    labeller : labeller instance, optional
+        Class providing the method ``make_label_vert`` to generate the labels in the plot titles.
+        Read the :ref:`label_guide` for more details and usage examples.
     ax: numpy array-like of matplotlib axes or bokeh figures, optional
         A 2D array of locations into which to plot the densities. If not supplied, Arviz will create
         its own array of plot areas (and return it).
@@ -85,23 +93,33 @@ def plot_ess(
         for extra methods lines labels. It accepts the additional
         key ``x`` to set ``xy=(text_kwargs["x"], mcse)``
     hline_kwargs: dict, optional
-        kwargs passed to ax.axhline for the horizontal minimum ESS line.
+        kwargs passed to :func:`~matplotlib.axes.Axes.axhline` or to :class:`~bokeh.models.Span`
+        depending on the backend for the horizontal minimum ESS line.
+        For relative ess evolution plots the kwargs are passed to
+        :func:`~matplotlib.axes.Axes.plot` or to :class:`~bokeh.plotting.figure.line`
     rug_kwargs: dict
         kwargs passed to rug plot.
     backend: str, optional
         Select plotting backend {"matplotlib","bokeh"}. Default "matplotlib".
     backend_kwargs: bool, optional
-        These are kwargs specific to the backend being used. For additional documentation
-        check the plotting method of the backend.
+        These are kwargs specific to the backend being used, passed to
+        :func:`matplotlib.pyplot.subplots` or :func:`bokeh.plotting.figure`.
+        For additional documentation check the plotting method of the backend.
     show: bool, optional
         Call backend show function.
     **kwargs
-        Passed as-is to plt.hist() or plt.plot() function depending on the value of `kind`.
+        Passed as-is to :meth:`mpl:matplotlib.axes.Axes.hist` or
+        :meth:`mpl:matplotlib.axes.Axes.plot` function depending on the
+        value of ``kind``.
 
     Returns
     -------
     axes: matplotlib axes or bokeh figures
 
+    See Also
+    --------
+    ess: Calculate estimate of the effective sample size.
+
     References
     ----------
     * Vehtari et al. (2019) see https://arxiv.org/abs/1903.08008
@@ -167,12 +185,14 @@ def plot_ess(
     valid_kinds = ("local", "quantile", "evolution")
     kind = kind.lower()
     if kind not in valid_kinds:
-        raise ValueError("Invalid kind, kind must be one of {} not {}".format(valid_kinds, kind))
+        raise ValueError(f"Invalid kind, kind must be one of {valid_kinds} not {kind}")
 
     if coords is None:
         coords = {}
     if "chain" in coords or "draw" in coords:
         raise ValueError("chain and draw are invalid coordinates for this kind of plot")
+    if labeller is None:
+        labeller = BaseLabeller()
     extra_methods = False if kind == "evolution" else extra_methods
 
     data = get_coords(convert_to_dataset(idata, group="posterior"), coords)
@@ -273,6 +293,7 @@ def plot_ess(
         n_samples=n_samples,
         relative=relative,
         min_ess=min_ess,
+        labeller=labeller,
         ylabel=ylabel,
         rug=rug,
         rug_kind=rug_kind,
