@@ -52,6 +52,13 @@ class TestDiagnostics:
         with pytest.raises(TypeError):
             bfmi(data)
 
+    def test_bfmi_correctly_transposed(self):
+        data = load_arviz_data("centered_eight")
+        vals1 = bfmi(data)
+        data.sample_stats["energy"] = data.sample_stats["energy"].T
+        vals2 = bfmi(data)
+        assert_almost_equal(vals1, vals2)
+
     def test_deterministic(self):
         """
         Test algorithm against posterior (R) convergence functions.
@@ -149,7 +156,7 @@ class TestDiagnostics:
         results = {}
         for key, coord_dict, _, vals in xarray_var_iter(posterior.posterior, combined=True):
             if coord_dict:
-                key = key + f".{list(coord_dict.values())[0] + 1}"
+                key = f"{key}.{list(coord_dict.values())[0] + 1}"
             results[key] = {func_name: func(vals) for func_name, func in funcs.items()}
         arviz_data = pd.DataFrame.from_dict(results).T.sort_index(axis=1).sort_index(axis=0)
 
@@ -194,10 +201,7 @@ class TestDiagnostics:
     @pytest.mark.parametrize("draw", (1, 2, 3, 4))
     def test_rhat_shape(self, method, chain, draw):
         """Confirm R-hat statistic returns nan."""
-        if chain is None:
-            data = np.random.randn(draw)
-        else:
-            data = np.random.randn(chain, draw)
+        data = np.random.randn(draw) if chain is None else np.random.randn(chain, draw)
         if (chain in (None, 1)) or (draw < 4):
             rhat_data = rhat(data, method=method)
             assert np.isnan(rhat_data)
@@ -237,8 +241,8 @@ class TestDiagnostics:
     )
     @pytest.mark.parametrize("relative", (True, False))
     def test_effective_sample_size_array(self, data, method, relative):
-        n_low = 100 if not relative else 100 / 400
-        n_high = 800 if not relative else 800 / 400
+        n_low = 100 / 400 if relative else 100
+        n_high = 800 / 400 if relative else 800
         if method in ("quantile", "tail"):
             ess_hat = ess(data, method=method, prob=0.34, relative=relative)
             if method == "tail":
@@ -280,27 +284,18 @@ class TestDiagnostics:
     @pytest.mark.parametrize("draw", (1, 2, 3, 4))
     @pytest.mark.parametrize("use_nan", (True, False))
     def test_effective_sample_size_nan(self, method, relative, chain, draw, use_nan):
-        if chain is None:
-            data = np.random.randn(draw)
-        else:
-            data = np.random.randn(chain, draw)
+        data = np.random.randn(draw) if chain is None else np.random.randn(chain, draw)
         if use_nan:
             data[0] = np.nan
+        if method in ("quantile", "tail"):
+            ess_value = ess(data, method=method, prob=0.34, relative=relative)
+        elif method == "local":
+            ess_value = ess(data, method=method, prob=(0.2, 0.3), relative=relative)
+        else:
+            ess_value = ess(data, method=method, relative=relative)
         if (draw < 4) or use_nan:
-            if method in ("quantile", "tail"):
-                ess_value = ess(data, method=method, prob=0.34, relative=relative)
-            elif method == "local":
-                ess_value = ess(data, method=method, prob=(0.2, 0.3), relative=relative)
-            else:
-                ess_value = ess(data, method=method, relative=relative)
             assert np.isnan(ess_value)
         else:
-            if method in ("quantile", "tail"):
-                ess_value = ess(data, method=method, prob=0.34, relative=relative)
-            elif method == "local":
-                ess_value = ess(data, method=method, prob=(0.2, 0.3), relative=relative)
-            else:
-                ess_value = ess(data, method=method, relative=relative)
             assert not np.isnan(ess_value)
         # test following only once tests are run
         if (method == "bulk") and (not relative) and (chain is None) and (draw == 4):
@@ -353,7 +348,7 @@ class TestDiagnostics:
     @pytest.mark.parametrize("relative", (True, False))
     @pytest.mark.parametrize("var_names", (None, "mu", ["mu", "tau"]))
     def test_effective_sample_size_dataset(self, data, method, var_names, relative):
-        n_low = 100 if not relative else 100 / (data.chain.size * data.draw.size)
+        n_low = 100 / (data.chain.size * data.draw.size) if relative else 100
         if method in ("quantile", "tail"):
             ess_hat = ess(data, var_names=var_names, method=method, prob=0.34, relative=relative)
         elif method == "local":
@@ -390,23 +385,16 @@ class TestDiagnostics:
     @pytest.mark.parametrize("draw", (1, 2, 3, 4))
     @pytest.mark.parametrize("use_nan", (True, False))
     def test_mcse_nan(self, mcse_method, chain, draw, use_nan):
-        if chain is None:
-            data = np.random.randn(draw)
-        else:
-            data = np.random.randn(chain, draw)
+        data = np.random.randn(draw) if chain is None else np.random.randn(chain, draw)
         if use_nan:
             data[0] = np.nan
+        if mcse_method == "quantile":
+            mcse_hat = mcse(data, method=mcse_method, prob=0.34)
+        else:
+            mcse_hat = mcse(data, method=mcse_method)
         if draw < 4 or use_nan:
-            if mcse_method == "quantile":
-                mcse_hat = mcse(data, method=mcse_method, prob=0.34)
-            else:
-                mcse_hat = mcse(data, method=mcse_method)
             assert np.isnan(mcse_hat)
         else:
-            if mcse_method == "quantile":
-                mcse_hat = mcse(data, method=mcse_method, prob=0.34)
-            else:
-                mcse_hat = mcse(data, method=mcse_method)
             assert not np.isnan(mcse_hat)
 
     @pytest.mark.parametrize("method", ("wrong_method", "quantile"))
